@@ -1,9 +1,9 @@
 package Pod::Weaver::Plugin::Sah::Schemas;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-19'; # DATE
+our $DATE = '2021-07-20'; # DATE
 our $DIST = 'Pod-Weaver-Plugin-Sah-Schemas'; # DIST
-our $VERSION = '0.065'; # VERSION
+our $VERSION = '0.066'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -56,6 +56,8 @@ sub weave_section {
                 last unless keys %schemas;
                 require Markdown::To::POD;
                 my @pod;
+                push @pod, "The following schemas are included in this distribution:\n\n";
+
                 push @pod, "=over\n\n";
                 for my $name (sort keys %schemas) {
                     my $sch = $schemas{$name};
@@ -179,6 +181,9 @@ _
                     last unless $egs && @$egs;
                     push @pod, "Sample data:\n\n";
                     for my $eg (@$egs) {
+                        # normalize non-defhash example
+                        $eg = {value=>$eg, valid=>1} if ref $eg ne 'HASH';
+
                         # XXX if dump is too long, use Data::Dump instead
                         my $value = exists $eg->{value} ? $eg->{value} :
                             $eg->{data};
@@ -244,7 +249,7 @@ Pod::Weaver::Plugin::Sah::Schemas - Plugin to use when building Sah::Schemas::*
 
 =head1 VERSION
 
-This document describes version 0.065 of Pod::Weaver::Plugin::Sah::Schemas (from Perl distribution Pod-Weaver-Plugin-Sah-Schemas), released on 2021-07-19.
+This document describes version 0.066 of Pod::Weaver::Plugin::Sah::Schemas (from Perl distribution Pod-Weaver-Plugin-Sah-Schemas), released on 2021-07-20.
 
 =head1 SYNOPSIS
 
